@@ -450,7 +450,7 @@ class RedisRoot:
                                     real_value = None
                                 value = real_value
                             elif django_field_param_name == 'model':
-                                create_redis_model_from_django_model(django_model, redis_root)
+                                create_redis_model_from_django_model(value, redis_root)
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
